<?php
/**
 * @file
 *  Informs Views about Masquerade's tables and fields.
 */

/**
 * Implements hook_views_data().
 *
 * @see hook_views_data()
 */
function masquerade_views_views_data() {
  $data['masquerade']['table']['group'] = t('Masquerade');

  // Because the masquerade table uses two user indicies
  // we have to make some aliases and tell views
  // to treat them separately.
  $data['masquerade']['table']['join'] = array(
    'user_as' => array(
      'left_table' => 'users',
      'left_field' => 'uid',
      'field' => 'uid_as',
    ),
    'user_is' => array(
      'left_table' => 'users',
      'left_field' => 'uid',
      'field' => 'uid_from',
    ),
  );

  // A faux field that should allow us to access any user ID.
  $data['users']['masquerade_as'] = array(
    'real field' => 'uid',
    'title' => t('Masquerade Link'),
    'help' => t('The user you want to masquerade as.'),
    'field' => array(
      'handler' => 'masquerade_handler_field_user',
      'click sortable' => TRUE,
    ),
    'relationship' => array(
      'handler' => 'views_handler_relationship',
      'base' => 'users',
      'base field' => 'uid',
      'field' => 'uid',
      'label' => t('user'),
    ),
  );

  // The session ID of the masquerader.
  $data['masquerade']['sid'] = array(
    'title' => t('Session SID'),
    'help' => t('The session ID of the person masquerading. This is normally NEVER shown, so use it with extreme caution.'),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
  );
  
  // Who is BEING masqueraded.
  $data['masquerade']['uid_as'] = array(
    'title' => t('Masquerade As'),
    'help' => t('The user this person is posing as.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
    ),
    'relationship' => array(
      'handler' => 'views_handler_relationship',
      'base' => 'users',
      'base field' => 'uid',
      'field' => 'uid_as',
      'label' => t('Masquerading as'),
    ),
  );

  // Who actually IS masquerading.
  $data['masquerade']['uid_from'] = array(
    'title' => t('Masquerade From'),
    'help' => t('The user this person actually is.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
    ),
    'relationship' => array(
      'handler' => 'views_handler_relationship',
      'base' => 'users',
      'base field' => 'uid',
      'field' => 'uid_from',
      'label' => t('Who is masquerading'),
    ),
  );

  return $data;
}
